@@ -4,17 +4,17 @@ Describes Python file type
 """
 from re import findall, sub, MULTILINE, IGNORECASE
 
-from ..abc import ABCFileType
+from . import Py
 
 
-class FastApi(ABCFileType):
+class FastApi(Py):
     """
     Provides Python file type behavior
     """
 
     @staticmethod
     def process_funcs(
-            functions: list[tuple[str, str, str, str, str, str, str, str]]
+            functions: list[tuple]
     ) -> str:
         """
         Process functions and methods in .py files
@@ -24,57 +24,25 @@ class FastApi(ABCFileType):
         :return: md formatted string
         """
         methods_text = []
-        for method in functions:
-            decorator, _, is_async, name, arguments, return_type, _, docs = method
-            # description
-            description = findall(r'\s*([^:]+)', docs)
-            description = description[0].rstrip(' \n') if description else ''
-            # decorators
-            decorators = [i.strip() for i in decorator.split('@')[1:]] if decorator else []
+        for desc, decorators, _, arguments, _, _ in FastApi._process(functions):
             req_method, req_route = '', ''
+            # Find method and route path
             for decorator in decorators:
                 data = findall(
-                    r'(get|post|put|patch|delete|options|copy|link|unlink|purge|head)\((\'[^\']+?\'|"[^"]+")\)',
+                    r'(get|post|put|patch|delete|options|copy|link|unlink|purge|head)'
+                    r'\((\'[^\']+?\'|"[^"]+")\)',
                     decorator, IGNORECASE)
                 if data:
                     data = data[0]
                     req_method, req_route = data[0].upper(), data[1].strip('"').strip("'")
             if not req_method and not req_route:
                 continue
-            # return type
-            return_type = findall(r'->\s*([^:]+):', return_type)
-            return_type = f' -> {return_type[0]}' if return_type else ''
-            # arguments
-            arguments = arguments[1:-1]
-            arguments_typed = sub(r'\s+', r' ', arguments).split(',')
-            arguments_typed = list(filter(lambda x: bool(x[0]), [
-                (
-                    i.split(':', 1)[0].strip(),
-                    i.split(':', 1)[1].split('=')[0].strip() if ':' in i else '',
-                    i.split('=', 1)[1].strip() if '=' in i else ''
-                ) for i in arguments_typed
-            ]))
-            arguments = []
-            for arg in arguments_typed:
-                arg_name, arg_type, default_value = arg
-                arg_desc = findall(r':param\s+' + arg_name.strip() + r'\s*:\s+([^\n]+)', docs)
-                arguments.append({
-                    'name': arg_name,
-                    'desc': arg_desc[0].strip() if arg_desc else '',
-                    'text': f'{arg_name}: {arg_type} = {default_value}'
-                    if default_value else f'{arg_name}: {arg_type}'
-                    if arg_type else arg_name
-                })
-            arguments_text = ",\n    ".join([i["text"] for i in arguments])
             params = '\n- '.join([f'`{i["name"]}` - {i["desc"]}' for i in arguments if i['desc']])
             params = f'\n- {params}' if params else ''
-            decorator_text = '\n@'.join(decorators)
-            decorator_text = f'@{decorator_text}\n' if decorators else ''
-            arguments_text = f'\n    {arguments_text}\n' if arguments_text else ''
             query_text = f'#### Query Params:\n{params}'
             methods_text.append(
                 f'\n```http\n{req_method} {req_route} HTTP/1.1\n```'
-                f'\n{description}\n{query_text}\n')
+                f'\n{desc}\n{query_text}\n')
         return '\n___\n'.join(methods_text)
 
     @staticmethod
@@ -101,8 +69,8 @@ class FastApi(ABCFileType):
         # Handle classes
         classes = findall(r'(class +([^:]+):\n(\s+)[^\n]+(\n+\3[ \S]*)+)', source)
         classes_text = []
-        for c in classes:
-            class_code = c[0]
+        for class_data in classes:
+            class_code = class_data[0]
             name = findall(r'class +(\w+)', class_code)[0]
             doc = findall(r'class[^\n]+\s+"{3}\s*([\s\S]+?)"{3}', class_code)
             doc = f'> {doc[0]}' if doc else ''
@@ -110,7 +78,7 @@ class FastApi(ABCFileType):
             # Handle class methods
             methods = findall(
                 r"^\s*((@[\S]+\(\)|@[\S]+\([\S\s]+?\)|\s*|@[\S]+\s*)+)?"
-                r"\s+(async +)?def +([^\s(]+)(\(\)|\([\s\S]+?\))(\s*->\s*[^:]+:|\s*:)"
+                r"\s+(async +)?def +([^_][^\s(]+)(\(\)|\([\s\S]+?\))(\s*->\s*[^:]+:|\s*:)"
                 r"\s+(\"{3}([\s\S]+?)\"{3})?",
                 class_code,
                 MULTILINE
@@ -126,7 +94,7 @@ class FastApi(ABCFileType):
         # Handle functions
         functions = findall(
             r'^((@[\S]+\s*\(\)\s*|@[\S]+\s*\([\s\S]+?\)\s*|@[\S]+\s*)+)?\s+'
-            r'^(async +)?def +([^\s(]+)(\(\)|\([\s\S]+?\))(\s*->\s*[^:]+:|\s*:)'
+            r'^(async +)?def +([^_][^\s(]+)(\(\)|\([\s\S]+?\))(\s*->\s*[^:]+:|\s*:)'
             r'\s+(\"{3}([\s\S]+?)\"{3})?',
             source,
             MULTILINE
