@@ -3,6 +3,7 @@
 Describes Python file type
 """
 from re import findall, sub, MULTILINE
+from typing import Iterable
 
 from ..abc import ABCFileType
 
@@ -13,19 +14,9 @@ class Py(ABCFileType):
     """
 
     @staticmethod
-    def process_funcs(
-            functions: list[tuple[str, str, str, str, str, str, str, str]]
-    ) -> str:
-        """
-        Process functions and methods in .py files
-
-        :param source: source python file
-        :param functions: list of parsed functions (via regex)
-        :return: md formatted string
-        """
-        methods_text = []
-        for method in functions:
-            decorator, _, is_async, name, arguments, return_type, _, docs = method
+    def _process(functions: list[tuple]) -> Iterable[tuple[str]]:
+        for i in functions:
+            decorator, _, is_async, name, arguments, return_type, _, docs = i
             # description
             description = findall(r'\s*([^:]+)', docs)
             description = description[0].rstrip(' \n') if description else ''
@@ -55,6 +46,21 @@ class Py(ABCFileType):
                     if default_value else f'{arg_name}: {arg_type}'
                     if arg_type else arg_name
                 })
+            yield description, decorators, return_type, arguments, is_async, name
+
+    @staticmethod
+    def process_funcs(
+            functions: list[tuple]
+    ) -> str:
+        """
+        Process functions and methods in .py files
+
+        :param source: source python file
+        :param functions: list of parsed functions (via regex)
+        :return: md formatted string
+        """
+        methods_text = []
+        for desc, decorators, ret_type, arguments, is_async, name in Py._process(functions):
             arguments_text = ",\n    ".join([i["text"] for i in arguments])
             params = '\n- '.join([f'`{i["name"]}` - {i["desc"]}' for i in arguments if i['desc']])
             params = f'\n- {params}' if params else ''
@@ -62,8 +68,9 @@ class Py(ABCFileType):
             decorator_text = f'@{decorator_text}\n' if decorators else ''
             arguments_text = f'\n    {arguments_text}\n' if arguments_text else ''
             methods_text.append(
-                f'\n```python\n{decorator_text}{is_async}def {name}({arguments_text}){return_type}:\n```'
-                f'\n{description}\n{params}\n')
+                f'\n```python\n{decorator_text}{is_async}def '
+                f'{name}({arguments_text}){ret_type}:\n```'
+                f'\n{desc}\n{params}\n')
         return '\n___\n'.join(methods_text)
 
     @staticmethod
@@ -90,8 +97,8 @@ class Py(ABCFileType):
         # Handle classes
         classes = findall(r'(class +([^:]+):\n(\s+)[^\n]+(\n+\3[ \S]*)+)', source)
         classes_text = []
-        for c in classes:
-            class_code = c[0]
+        for class_data in classes:
+            class_code = class_data[0]
             name = findall(r'class +(\w+)', class_code)[0]
             doc = findall(r'class[^\n]+\s+"{3}\s*([\s\S]+?)"{3}', class_code)
             doc = f'> {doc[0]}' if doc else ''
@@ -99,7 +106,7 @@ class Py(ABCFileType):
             # Handle class methods
             methods = findall(
                 r"^\s*((@[\S]+\(\)|@[\S]+\([\S\s]+?\)|\s*|@[\S]+\s*)+)?"
-                r"\s+(async +)?def +([^\s(]+)(\(\)|\([\s\S]+?\))(\s*->\s*[^:]+:|\s*:)"
+                r"\s+(async +)?def +([^_][^\s(]+)(\(\)|\([\s\S]+?\))(\s*->\s*[^:]+:|\s*:)"
                 r"\s+(\"{3}([\s\S]+?)\"{3})?",
                 class_code,
                 MULTILINE
@@ -115,7 +122,7 @@ class Py(ABCFileType):
         # Handle functions
         functions = findall(
             r'^((@[\S]+\s*\(\)\s*|@[\S]+\s*\([\s\S]+?\)\s*|@[\S]+\s*)+)?\s+'
-            r'^(async +)?def +([^\s(]+)(\(\)|\([\s\S]+?\))(\s*->\s*[^:]+:|\s*:)'
+            r'^(async +)?def +([^_][^\s(]+)(\(\)|\([\s\S]+?\))(\s*->\s*[^:]+:|\s*:)'
             r'\s+(\"{3}([\s\S]+?)\"{3})?',
             source,
             MULTILINE
