@@ -5,6 +5,7 @@ Autodoc CLI
 import os
 from os import path
 from glob import glob
+from pprint import pprint
 
 import click
 
@@ -29,9 +30,12 @@ def hapdoc():
 
 @hapdoc.command()
 def project_types():
-    ptypes = all_project_types()
-    for t in ptypes:
-        click.echo(f'- {t}')
+    """
+    Shows all available project types
+    """
+    all_types = all_project_types()
+    for project_type in all_types:
+        click.echo(f'- {project_type}')
 
 
 @hapdoc.command()
@@ -80,12 +84,12 @@ def gen(
         empty_char=' ',
         show_percent=True,
         length=1,
-    ) as bar:
+    ) as progress:
         for i in generate(
                 project_path, None, ignore_list, document_type, extend, output
         ):
-            bar.length = i[1]
-            bar.update(i[0])
+            progress.length = i[1]
+            progress.update(i[0])
 
 
 @hapdoc.command()
@@ -177,47 +181,47 @@ def serve(
         directory = [i for i in mdf.split(os.sep) if i]
         mdf = mdf.replace('\\', '/')
         print(directory)
-        s: dict = sidebar
-        for i, p in enumerate(directory):
+        temp_sidebar: dict = sidebar
+        for idx, temp_path in enumerate(directory):
             # File
-            print(i, p, len(directory))
-            if i == len(directory)-1:
-                file = p.rsplit('.', 1)[0]
-                print(s)
-                s[file] = {
+            print(idx, temp_path, len(directory))
+            if idx == len(directory)-1:
+                file = temp_path.rsplit('.', 1)[0]
+                print(temp_sidebar)
+                temp_sidebar[file] = {
                     '_data': {
                         'id': mdf.replace('\\', '_'),
                         'title': file,
-                        'url': f'/docs/{mdf}'
+                        'url': f'/{mdf}'
                     },
                     '_items': {}
                 }
             else:
                 # Directory
-                if p in s:
-                    s = s[p]['_items']
+                if temp_path in temp_sidebar:
+                    temp_sidebar = temp_sidebar[temp_path]['_items']
                 else:
-                    s[p] = {
+                    temp_sidebar[temp_path] = {
                         '_data': {
                             'id': mdf.replace('\\', '_'),
-                            'title': p,
+                            'title': temp_path,
                             'url': ''
                         },
                         '_items': {}
                     }
-                    s = s[p]['_items']
-    print(sidebar)
+                    temp_sidebar = temp_sidebar[temp_path]['_items']
+    pprint(sidebar)
 
-    @app.get('/docs/{doc:path}')
+    @app.get('/{doc:path}')
     async def get_md_at(doc: str):
         if not doc.endswith('.md'):
             doc += '.md'
-        p = path.join(docs, doc)
-        print(p)
-        if path.exists(p) and path.isfile(p):
-            with open(p, 'r', encoding='utf-8') as f:
-                data = f.read()
-            p = p.replace('\\', '/').rstrip('/')
+        full_path = path.join(docs, doc)
+        print(full_path)
+        if path.exists(full_path) and path.isfile(full_path):
+            with open(full_path, 'r', encoding='utf-8') as filename:
+                data = filename.read()
+            full_path = full_path.replace('\\', '/').rstrip('/')
             return HTMLResponse(
                 template.render(
                     pageData=Md2Html.cast(data),
@@ -229,7 +233,7 @@ def serve(
                     accentColor=accent_color,
                     backgroundColor=background_color,
                     surfaceColor=surface_color,
-                    selected=p
+                    selected=doc
                 )
             )
         return HTMLResponse(
